==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/wxwidgets_8h.js <==
var wxwidgets_8h =
[
    [ "wxPLDevBase", "classwxPLDevBase.html", "classwxPLDevBase" ],
    [ "wxPLDevDC", "classwxPLDevDC.html", "classwxPLDevDC" ],
    [ "dev_entry", "structdev__entry.html", "structdev__entry" ],
    [ "wxPLplotApp", "classwxPLplotApp.html", "classwxPLplotApp" ],
    [ "wxPLplotWindow", "classwxPLplotWindow.html", "classwxPLplotWindow" ],
    [ "wxPLplotFrame", "classwxPLplotFrame.html", "classwxPLplotFrame" ],
    [ "wxGetSizeDialog", "classwxGetSizeDialog.html", "classwxGetSizeDialog" ],
    [ "CANVAS_HEIGHT", "wxwidgets_8h.html#ac8417e7f15a5262562983c1febe9e35e", null ],
    [ "CANVAS_WIDTH", "wxwidgets_8h.html#aa04ece9d00a940c9b1968887f16faeb3", null ],
    [ "DECLARE_PLAPP", "wxwidgets_8h.html#a5eda1e630d912b7d19a2aa0358ae8e78", null ],
    [ "DEVICE_PIXELS_PER_IN", "wxwidgets_8h.html#ac27be500dbb52509acecc23bb0eb7c54", null ],
    [ "DEVICE_PIXELS_PER_MM", "wxwidgets_8h.html#a11f2550b698a4ded14be08a8412314e9", null ],
    [ "IMPLEMENT_PLAPP_NO_MAIN", "wxwidgets_8h.html#aca6a78edf82d921ecc98a95a8d8aa702", null ],
    [ "LOCATE_INVOKED_VIA_API", "wxwidgets_8h.html#affae47a7165768dc8a355f3f7445b66b", null ],
    [ "LOCATE_INVOKED_VIA_DRIVER", "wxwidgets_8h.html#a96b6dcbd0661e2f7627f2ff22979d2d1", null ],
    [ "MAX_COMCOUNT", "wxwidgets_8h.html#a814203a8c6f8163793ee68dfeb39378d", null ],
    [ "max_number_of_grey_levels_used_in_text_smoothing", "wxwidgets_8h.html#a596c4e254d44ea11d5f8d6c173ccdc07", null ],
    [ "MM_PER_IN", "wxwidgets_8h.html#a86b7b8e83f31c708429ce71bf3dcf8b1", null ],
    [ "NDEV", "wxwidgets_8h.html#aa564a41c8409694da49b0badf2bb2853", null ],
    [ "PLOT_HEIGHT", "wxwidgets_8h.html#a2b49d5c686e9bd4f2ec6a3005eb798a5", null ],
    [ "PLOT_WIDTH", "wxwidgets_8h.html#a1fc4b17a5ce75463f2c6737654058dc9", null ],
    [ "VIRTUAL_PIXELS_PER_IN", "wxwidgets_8h.html#ae585952b2d5efb82ea2b338a07904c74", null ],
    [ "VIRTUAL_PIXELS_PER_MM", "wxwidgets_8h.html#ae4197bf633b93ea9a2b59258b5b1be6a", null ],
    [ "VSCALE", "wxwidgets_8h.html#ac51ccb923f4c4f470f00c1f9aa6e2c2b", null ],
    [ "WX_SUPPRESS_UNUSED_WARN", "wxwidgets_8h.html#abcb208242a04752a981fd1c734a2de07", null ],
    [ "wxBACKEND_AGG", "wxwidgets_8h.html#ac1e6989e8f5bb9f9f61431a4add40424", null ],
    [ "wxBACKEND_DC", "wxwidgets_8h.html#aeaf9111de69fb4368771d0b8c452567d", null ],
    [ "wxBACKEND_GC", "wxwidgets_8h.html#a4db9fcac7fce693c88c8449b81c915dd", null ],
    [ "wxPL_Save", "wxwidgets_8h.html#a99fb83031ce9923c84392b4e92f956b5ad45f48e56d695058c3c283baafb2d02e", null ],
    [ "wxPL_Next", "wxwidgets_8h.html#a99fb83031ce9923c84392b4e92f956b5ac91b32662e3b12cba7ec599923fd3f49", null ],
    [ "wxPL_Locate", "wxwidgets_8h.html#a99fb83031ce9923c84392b4e92f956b5ad57da649f028d7ea5286bf797aaf9b7f", null ],
    [ "wxPL_Orientation_0", "wxwidgets_8h.html#a99fb83031ce9923c84392b4e92f956b5ad11da16c77e1cf789b36b590e472327f", null ],
    [ "wxPL_Orientation_90", "wxwidgets_8h.html#a99fb83031ce9923c84392b4e92f956b5a6932dd8f9b0cc8bf1b90f2d358a9f468", null ],
    [ "wxPL_Orientation_180", "wxwidgets_8h.html#a99fb83031ce9923c84392b4e92f956b5adde8f6607ed2e4ea8d3f1b1557fdbb1b", null ],
    [ "wxPL_Orientation_270", "wxwidgets_8h.html#a99fb83031ce9923c84392b4e92f956b5af22418ef740260b32034ddc9a9cb0148", null ],
    [ "Log_Debug", "wxwidgets_8h.html#ab1277ea7aa81e2c31a4cbbe04e3f802b", null ],
    [ "Log_Verbose", "wxwidgets_8h.html#a4ac7c6cbc53d0a1a1180d76836d0ae15", null ],
    [ "plD_bop_wxwidgets", "wxwidgets_8h.html#ad74eeaa5e1922ea1fab185786c172be0", null ],
    [ "plD_eop_wxwidgets", "wxwidgets_8h.html#a28455e43dfd0a1ed3c5f70f5954ee4e0", null ],
    [ "plD_erroraborthandler_wxwidgets", "wxwidgets_8h.html#a25466f813e049cbb29374128fd0c9660", null ],
    [ "plD_errorexithandler_wxwidgets", "wxwidgets_8h.html#a6df3ba7c8398b263e9bafc2ed800a94b", null ],
    [ "plD_esc_wxwidgets", "wxwidgets_8h.html#a2df717037e3fd4ca9084c6cd1fd72229", null ],
    [ "plD_init_wxpng", "wxwidgets_8h.html#a4798081d428df271b10ddaae05435b21", null ],
    [ "plD_init_wxwidgets", "wxwidgets_8h.html#a3a8644936ef24419143cb7a474c667b7", null ],
    [ "plD_line_wxwidgets", "wxwidgets_8h.html#ac08215d27d48f5b67d4c822f3f4be18e", null ],
    [ "plD_polyline_wxwidgets", "wxwidgets_8h.html#ae2496920c4414c0d73a2d99a84847c84", null ],
    [ "plD_state_wxwidgets", "wxwidgets_8h.html#aa0cabe346e76ee92fa71432d75e24484", null ],
    [ "plD_tidy_wxwidgets", "wxwidgets_8h.html#a282d423773fa7d99a0309081a594ca27", null ],
    [ "Use", "wxwidgets_8h.html#acd74d9b9b8ef45e8ef2651b5074d4ae8", null ],
    [ "WX_DEFINE_ARRAY", "wxwidgets_8h.html#ac1a4f9bf8e1be723e2607be5d73feda1", null ],
    [ "wx_set_buffer", "wxwidgets_8h.html#ab28e3bfaaa5fa87f81c7fa0f8f4b9003", null ],
    [ "wx_set_dc", "wxwidgets_8h.html#a01560f348183083351fa4edc2a5d669f", null ],
    [ "wx_set_size", "wxwidgets_8h.html#ada45d19fe091fcd5cdf52563aa8fe0b0", null ],
    [ "fontFamilyLookup", "wxwidgets_8h.html#a98e63d912a13da0ed2a2568547e55479", null ],
    [ "fontStyleLookup", "wxwidgets_8h.html#a9527465bcb32eac9a8b9d7f58567e825", null ],
    [ "fontWeightLookup", "wxwidgets_8h.html#a9f01825db2b4a454b7c875fe6cd7c385", null ]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/wxwidgets_8h.js <==
var wxwidgets_8h =
[
    [ "FontGrabber", "classFontGrabber.html", "classFontGrabber" ],
    [ "wxPLDevice", "classwxPLDevice.html", "classwxPLDevice" ],
    [ "dev_entry", "structdev__entry.html", "structdev__entry" ],
    [ "Log_Debug", "wxwidgets_8h.html#ab1277ea7aa81e2c31a4cbbe04e3f802b", null ],
    [ "Log_Verbose", "wxwidgets_8h.html#a4ac7c6cbc53d0a1a1180d76836d0ae15", null ],
    [ "plD_bop_wxwidgets", "wxwidgets_8h.html#ad74eeaa5e1922ea1fab185786c172be0", null ],
    [ "plD_eop_wxwidgets", "wxwidgets_8h.html#a28455e43dfd0a1ed3c5f70f5954ee4e0", null ],
    [ "plD_esc_wxwidgets", "wxwidgets_8h.html#a2df717037e3fd4ca9084c6cd1fd72229", null ],
    [ "plD_init_wxpng", "wxwidgets_8h.html#a4798081d428df271b10ddaae05435b21", null ],
    [ "plD_init_wxwidgets", "wxwidgets_8h.html#a3a8644936ef24419143cb7a474c667b7", null ],
    [ "plD_line_wxwidgets", "wxwidgets_8h.html#ac08215d27d48f5b67d4c822f3f4be18e", null ],
    [ "plD_polyline_wxwidgets", "wxwidgets_8h.html#ae2496920c4414c0d73a2d99a84847c84", null ],
    [ "plD_state_wxwidgets", "wxwidgets_8h.html#aa0cabe346e76ee92fa71432d75e24484", null ],
    [ "plD_tidy_wxwidgets", "wxwidgets_8h.html#a282d423773fa7d99a0309081a594ca27", null ],
    [ "wx_set_buffer", "wxwidgets_8h.html#ab28e3bfaaa5fa87f81c7fa0f8f4b9003", null ],
    [ "wx_set_dc", "wxwidgets_8h.html#a01560f348183083351fa4edc2a5d669f", null ],
    [ "fontFamilyLookup", "wxwidgets_8h.html#a98e63d912a13da0ed2a2568547e55479", null ],
    [ "fontStyleLookup", "wxwidgets_8h.html#a9527465bcb32eac9a8b9d7f58567e825", null ],
    [ "fontWeightLookup", "wxwidgets_8h.html#a9f01825db2b4a454b7c875fe6cd7c385", null ]
];
